@@ -1,4 +1,5 @@
 from typing import Union
+
 import numpy as np
 import tensorflow as tf
 
@@ -8,10 +9,6 @@ from .regularizers import Norm, TotalVariation2D
 
 
 class ActivationMaximization(ActivationMaximizationBase):
-    """ActivationMaximization of legacy version.
-
-        This class was introduced in v0.7.0 to keep compatibility with the past versions.
-    """
     def __call__(self,
                  score,
                  seed_input=None,
@@ -21,7 +18,6 @@ class ActivationMaximization(ActivationMaximizationBase):
                                Norm(weight=0.003, p=1)],
                  steps=200,
                  optimizer=None,
-                 normalize_gradient=None,
                  gradient_modifier=None,
                  callbacks=None,
                  training=False,
